*=====================================================================================*
*                                  prep.do                                     *
*=====================================================================================*

*-------------------------------------------------------------------------------------*
*  van den Berg, Kalmijn, Leopold, 2019, replication files                            *
*  last update: 1 April 2019                                                          *
*  data: soeplong 1984-2015, version 32.1, release 2017                               *
*-------------------------------------------------------------------------------------*

clear
set more off

*-----------------------------------------------------------------------------*
*  Prepare data sets                                                          *
*-----------------------------------------------------------------------------*
*-----------------------------------------------------------------------------*
* Income data 

use "${data}\pequiv.dta"

** Equivalise post-government household income (square root scale)
replace i11102 = . if i11102 < 0
gen einc = i11102 / (d11106^0.5)

** Weight by consumer price index
clonevar price 	= y11101
replace price	= . if price < 0
gen pw 			= 100/price
gen eincp		= einc * pw
replace eincp 	= . if eincp < 2000 // set implausible values to missing

** Calculate percent of year-specific median income
gen pmi = .
	forvalues x = 1984/2015 {
		 sum eincp if syear == `x', d
		 replace pmi = eincp/r(p50) if syear == `x'		//  % of median income
		 }
	*
	recode pmi	(0/.59999    	= 1 "< 60%"      	) ///
				(.60/.999999  	= 2 "60% - 100%"  	) ///
				(1.00/1.499999	= 3 "100% - 150%"  	) ///
				(1.50/1000000   = 4 "> 150%"    	) ///
				(else        	= 5 "Missing"    	) ///
		 , gen(pmic)
label variable pmic "Percent of year-specific median income (categorical)"

recode pmi 	(0/.499999 	= 	1 	"Poor") ///
			(else		=	0	"Not poor") ///
			, gen(poor) 

keep pid hid syear pmic poor
					
save "${posted}\pmic.dta",replace 

*-----------------------------------------------------------------------------*
* Parents' identifier
/* We make the identifier of the parents via these datasets:
- First year young adult is observed after age 16. 
- Kidl */

** Make identifier by using the relation to head of household. 
use "${data}\pbrutto.dta"
merge 1:1 pid syear using  "${data}\pgen.dta", nogen keepusing (pid syear pgpartnr)

recode pid pgpartnr (-2000/0 = . )
tostring pid pgpartnr, gen(pidb pgpartnerb)
gen head			=	pidb 		if 	stell==0  					
gen headp			=	pidb 		if 	stell==11 | stell==13		
gen headp2			=	pgpartner	if 	stell==0

foreach var of varlist head headp headp2 {
	sort hid syear
	bys hid syear: egen `var'a		=	mode(`var')
	}
	*
	
gen bio1		 	=	heada 		if		stell==20 				| 	///
											stell==21	
	replace bio1	=	headpa		if		stell==22 & bio1==""	|	///
											stell==12 & bio1==""	
	replace bio1	=	headp2a		if		stell==22 & bio1==""	| 	///
											stell==12 & bio1==""		

gen age	=	syear	-	geburt
keep if age>15			// keep only observations after age 15 to identify parents in adolescence 
sort pid syear
bys pid: gen n = _n
keep if n==1

keep pid syear bio1  

save "${posted}\parentid.dta", replace

** Make identifier by using kidl
use "${data}\kidl.dta" 
merge 1:1 pid syear using  "${data}\pequiv.dta", keep( 1 3) ///
		keepusing(pid syear d11101)

gen birthyear = syear-d11101
replace k_phead=	. 	if k_rel!=3 & k_rel!=21 	
tostring k_phead k_pmum, replace

sort pid syear   
bysort pid : egen bio2 = mode(k_phead)				// head of household
bysort pid : egen bio3 = mode(k_pmum)				// mother
bysort pid: gen n=_n
keep if n==1
keep pid bio2 bio3 birthyear hid
save "${posted}\kidb.dta", replace

*-----------------------------------------------------------------------------*
* Prepare datafiles parents
/* We prepare data of the parents on:
- Their partner based on their partner's participation in the soep
- Family structure data from biol (retrospective at start participation soep) 
supplemented with prospective data 
- Prospective data on unemployment
-  */

** Prepare partnerdata parent with pl
// save data as partner's data (later to be merged with partner id parent) 
use "${data}\pl.dta"

keep pid syear plh0182 plh0171  
rename (pid plh0182) (pgpartnr partlifes)

save "${posted}\partn.dta", replace

** Prepare other data parent 
*** From biol 
use "${data}\biol.dta"

sort pid syear
bys pid: egen min_syear = min(syear)

keep if syear==min_syear				
keep pid ll0312-ll0320

*** Merge with other datasets
merge 1:m pid using  "${data}\pequiv.dta", ///
	keep(1 3) keepusing (syear d11102ll d11101 e11101 d11106 h11110) nogen
merge 1:1 pid syear using "${data}\pgen.dta", ///
	keep(1 3) keepusing(hid syear pgfamstd pgpartz pgmonth pgpartnr) nogen	
merge 1:1 pid syear using "${data}\pl.dta", ///
	keep(1 3) keepusing(pid hid syear plh0182 plh0171 plh0177 pld0133 pld0166  	///
						plb0021 plb0022) nogen
merge 1:1 pid syear using "${posted}\pmic.dta", ///
	keep(1 3)  nogen
merge m:1 hid syear using "${data}\hgen.dta", ///
	keep(1 3) keepusing(hid syear hgcondit hgowner hgsize hgseval ) nogen
merge m:1 pid using "${data}\ppfad.dta", keep (master matched) nogen ///
	keepusing (loc1989) 
merge m:1 hid syear using "${data}\hgen.dta", ///
	keep(1 3) keepusing(hid syear hgmoveyr) nogen	
merge m:1 pgpartnr syear using "${posted}\partn.dta", ///
	keep(1 3) nogen	
bys pid: egen max_syearp = max(syear)

*** Make marital history variables: yearmar* monthmar* famstat*
replace pgfamstd = 1 if pgpartz>=1 						 	// 	cohabiting also also as married. 
recode pgfamstd (1 6 7	 	= 	1 	"Married/Cohabiting")	///
				(2 3 4 8	=	2	"Single/ Divorced")		///  
				(5			=	3	"Widowed")				///
				(-5 -3 -1 	=	.	)						///
				, gen (famstat)

foreach num of numlist 1/5 {
	sort pid syear
	bys pid: replace famstat = famstat[_n-`num'] if famstat==.
	bys pid: replace famstat = famstat[_n+`num'] if famstat==. 
	}
	*

**** Make variable for change in marital status and year and partnernumber per change
// retrospective data supplement with prospective data 
bys pid: gen famstatbf	=	famstat[_n-1] 
gen changemar			=	1 	if famstatbf!=famstat & famstatbf!=. & famstat!=.
gen sychange			=	syear if changemar==1

gen mar1 		=	1 	if 	ll0312>1
gen mar2		=	2	if	ll0313==2
replace mar2	=	3	if 	ll0313==3
gen mar3		=	1	if	ll0315>1
gen mar4		=	2	if	ll0316==2
replace mar4	=	3	if 	ll0316==3
gen mar5		=	1	if	ll0318>1
gen mar6		=	2	if	ll0319==2
replace mar6	=	3 	if 	ll0319==3

rename 	(ll0312 ll0314 ll0315 ll0317 ll0318 ll0320) ///
		(ymar1 ymar2 ymar3 ymar4 ymar5 ymar6)
		
foreach num of numlist 1/6 {
replace ymar`num'	=	ymar`num'+1900 if ymar`num'<100 & ymar`num'>0
replace ymar`num'	=	.	if	ymar`num'<1900
}
*
foreach num of numlist 7/10 {
gen mar`num'	=	.
gen ymar`num'	=	.
}
*

sort pid syear
bys pid: egen min_syear = min(syear)
gen famstat1			= famstat 		if syear==min_syear
bys pid: egen famst1 	= max(famstat1)
replace mar1 			= famst1 		if syear==min_syear & mar1==.
replace ymar1 			= min_syear 	if ymar1==.
gen ymar0 = . 

foreach num of numlist 1/10 {
sort pid syear
bys pid: egen msychange		=	min(sychange)
replace mar`num'			=	famstat if syear==msychange & mar`num'==. & ymar`num'-1!=msychange
gen partmar`num'			=	pgpartnr if syear==msychange & mar`num'==. & ymar`num'-1!=msychange
replace ymar`num'			=	msychange if ymar`num'==.
bys pid: egen mar`num'a 	= 	max(mar`num')
bys pid: egen ymar`num'a 	= 	max(ymar`num')
replace mar`num' 			=	mar`num'a
replace	ymar`num'			=	ymar`num'a
replace sychange			= 	.	if ymar`num'==sychange
drop msychange
tostring partmar`num', replace
}
*

**** Unemployment parents
recode plb0022 (9 = 1) (else =0), gen(nwork)

*** Save 
bys pid syear: gen np2 = _n
keep if np2==1
destring pid, replace
drop if pid==.

tostring pid pgpartnr, replace
rename * x*

save "${posted}\parentsb.dta", replace

*-----------------------------------------------------------------------------*
*  Merge datasets                                                          	  *
*-----------------------------------------------------------------------------*
use "${posted}\pmic.dta", clear

merge 1:1 pid syear using "${data}\pequiv.dta", 								///
	keep(1 3) keepusing(pid hid syear l11102 d11102ll d11101 d11107  d11109 	///
						h11101 h11102 d11106) nogen
merge 1:1 pid syear using "${data}\pbrutto.dta", 								///
	keep(1 3) keepusing(pid syear stell pzug) nogen
merge 1:1 pid syear using "${data}\jugendl.dta", 								/// 
	keep(1 3) keepusing(pid syear  jl0233  jl0234 jl0392 jl0273 jl0013 jl0125  	///
						jl1402 jl0038) 
rename _merge mergedjugendl
merge 1:1 pid syear using "${data}\pl.dta", 									/// 
	keep(1 3) keepusing(pid hid syear pld0132 pld0133 plg0012 plb0022 plb0021 	///
						plg0014 plh0182 plh0174 plh0175 plh0171 plh0177 		///
						plg0012-plg0068 plh0033 pli0043) 
rename _merge mergedpl	
merge 1:1 pid syear using "${data}\pgen.dta", 									/// 
	keep(1 3) keepusing(pid syear pgfamstd pgmonth pgpartz pgpartnr) nogen
merge 1:1 pid syear using "${data}\ppfadl.dta", 								///
	keep(1 3) keepusing(gebjahr gebmonat)  nogen
merge m:1 hid syear using "${data}\hgen.dta", 									///
	keep(1 3) keepusing(hid syear hgcondit hgowner hgsize hgseval hgroom) nogen	
merge m:1 hid syear using "${data}\hbrutto.dta", 								///
	keep(1 3) keepusing(hid syear sampreg) nogen
merge m:1 pid using "${data}\ppfad.dta", 										///
	keep(1 3) keepusing(migback) nogen
merge m:1 pid using "${posted}\kidb.dta", 										///
	keep(1 3) nogen 
merge m:1 pid using "${posted}\parentid.dta", 									///
	keep(1 3) nogen 
 
drop if mergedjugendl==1 & mergedpl==1	// Only keep young adults who at least participated once in the soep

** Make all of the variables of jugendl on cluster level 
foreach var of varlist jl*{
	bys pid: egen `var'max = max(`var')
	replace `var' = `var'max
	drop `var'max
	}
	*

*-----------------------------------------------------------------------------*
*  Make variables		                                                      *
*-----------------------------------------------------------------------------*
***** Variables of the child
* Age
gen age = d11101
keep if age>15 & age<35							// keep only young adulthood
sort pid syear
bys pid: egen min_age = min(age)
bys pid: egen max_age = max(age)
gen ageyrs = int(age)


* Live with parents
gen livepar 	= 1 if 	stell==12 | stell>19 & stell<25
gen livpary1a 	= 1 if 	min_age==age & livepar==1
bys pid: egen livpary1 = max(livpary1a)
drop if livpary1==.								// keep only youth living with parents at start

** Make identifier parents
// merge with two parents if there are two identifiers 
gen biopar  = "." 
gen biopar2	= "." 
foreach var of varlist bio1 bio2 bio3 {
	replace `var'	=	"."		if `var'=="" 	| `var'=="-2"
	replace biopar	=	`var'	if biopar=="." 	
	replace biopar2	=	`var'	if biopar2=="." & biopar!=`var' 
	}
	*

rename (syear biopar) (xsyear xpid)
merge m:1 xpid xsyear using "${posted}\parentsb.dta", keep(1 3)
rename _merge biomerge
rename x* biox*

rename (bioxsyear biopar2) (xsyear xpid)
merge m:1 xpid xsyear using "${posted}\parentsb.dta", keep(1 3)
rename _merge biomerge2
rename xsyear syear
rename x* bio2x*

gen residbioxa  = 1 if bioxhid==hid
gen residbio2xa = 1 if bio2xhid==hid
bys pid: egen residbiox  = max(residbioxa)
bys pid: egen residbio2x = max(residbio2xa)

gen resid 		= 1 if residbiox==1 & residbio2x==.			
replace resid 	= 2 if residbiox==. & residbio2x==1
replace resid 	= 3 if residbiox==1 & residbio2x==1

* Leaving home and year/n/age left
// based on relation to head of the household and presence of parents in household
gen leaveh = 1 if 	livepar==. & 	hid!=bioxhid & hid!=bio2xhid & stell!=12 & stell<20 | ///
									hid!=bioxhid & hid!=bio2xhid & stell!=12 & stell>25
recode leaveh (. = 0 )

sort pid syear
bys pid: gen n =_n
foreach var of varlist n age syear { 
gen `var'mo				= `var' 	if leaveh==1
bys pid: egen `var'mov	= min(`var'mo)
}
*

** Identifier of last parent lived with
gen residbioxa1 		= 1 if bioxhid==hid  & n==nmov-1
gen residbio2xa1 		= 1 if bio2xhid==hid & n==nmov-1
bys pid: egen residbiox1 = max(residbioxa1)
bys pid: egen residbio2x1 = max(residbio2xa1)

gen resid1		= 1 if residbiox1==1 & residbio2x1==.			
replace resid1 	= 2 if residbiox1==. & residbio2x1==1
replace resid1 	= 3 if residbiox1==1 & residbio2x1==1

* Returning home
gen return = 1 if 	stell>=20 & stell<=24 & syear>syearmov 	& syearmov!=.					| 	///
					stell==12 & syear>syearmov & syearmov!=.								|	///
					stell>11 & stell!=13 & hid==bioxhid  & syear>syearmov & syearmov!=. 	| 	///
					stell>11 & stell!=13 & hid==bio2xhid & syear>syearmov & syearmov!=.
recode return (. = 0)

* Gender, male
recode d11102ll (1=1) (2=0), gen(male)

* Income, pmic
sort pid syear n 
foreach num of numlist 1/3 {
bys pid: replace pmic = pmic[_n-`num'] if pmic==5 & pmic[_n-`num']!=. & hid[_n-`num']==hid
bys pid: replace pmic = pmic[_n+`num'] if pmic==5 & pmic[_n+`num']!=. & hid[_n+`num']==hid
}
*

* Life satisfaction, lsat
recode plh0182 (-5 -2 -1 = .), gen(lsat)
replace lsat = jl0392 if lsat==. & jl0392>=0 & jl0392!=. & age==min_age			// youth questionnaire data 
sort pid syear
bys pid: replace lsat = lsat[_n-1] if lsat==.
bys pid: replace lsat = lsat[_n+1] if lsat==.		
					
* Satisfaction with dwelling, dsat
recode plh0171 (-5 -2 -1 = .), gen(dsat)
sort pid syear
bys pid: replace dsat = dsat[_n-1] if plh0171==. 
bys pid: replace dsat = dsat[_n+1] if plh0171==.
bys pid hid: egen modedsat = mode(dsat) 
replace dsat = modedsat if dsat==.

* Satisfaction with health, hsat
recode plh0177 (-5 -2 -1 = .), gen(hsat)
sort pid syear
bys pid: replace hsat = hsat[_n-1] if hsat==. 
bys pid: replace hsat = hsat[_n+1] if hsat==.

* Housing conditions, hcon
recode hgcondit (-1 = . ) (1=0) (2 3 4 =1) , gen(hcon)
sort hid syear
bys 	hid: egen modehcon 	= mode(hcon) 
replace hcon 	= modehcon if hcon==.

* Homeowner
recode hgowner (1=1 "Owner") (2 3 = 0 "Tenant") (else = .), gen(owner)
sort hid syear
bys 	hid: egen modowner 	= mode(owner) 
replace owner 	= modowner if owner==.

* Number of other household members that are children of head household, hhdmem
gen hhdmem = h11101 + h11102
replace hhdmem = hhdmem - 1 if age<18

* Region, region 
recode sampreg (1 =0 "West ") ( 2 = 1 "East") (else = 2 "Unknown region"), gen(region)
replace region = 0 if bioxloc1989==1 &  region==2 | bio2xloc1989==1 &  region==2 
replace region = 1 if bioxloc1989==2 &  region==2 | bio2xloc1989==2 &  region==2 

* Migration background
recode migback (-1 = .) (1 = 1 "native") (2 4 = 2 "1st generation") (3 = 3 "2nd generation") ///
				, gen(mig)

				
* Employment variables
** Activity status, eduemp (used in leaving home analysis) 
// there are variables per education level (e.g. plg0023), some only used in certain waves 
recode plb0022 (1 2 4 5 8 = 1) // different kind of employment coded as employed

gen eduemploy		=	.
replace eduemploy 	=	1	if	plg0013>=1 & plg0013<=6						|	/// 
								plg0016==4 	| plg0019==1
replace eduemploy	=	2	if	plg0016==1 	| plg0016==2	|	plg0016==3	| 	///	 	
								plg0016==5 	| plg0017==1 	|	plb0022==3 	|	/// 
								plg0021>=1 	& plg0021<=8 	| 	plg0022==1	|	/// 
								plg0023>=1 	& plg0023<=8 	| 	plg0024==1 	|	///
								plg0025==1 	| plg0026==1	|	plg0027==1	|	///
								plg0028==1	| plg0029==1	|	plg0038==1	|	///
								plg0039==1	| plg0040==1	|	plg0051==1	|	///
								plg0052==1	| plg0053==1	| 	plg0060==1	|	///
								plg0062==1	| plg0063==1	| 	plg0065==1	|	///
								plg0066==1	| plg0067==1	|	plg0068==1	
replace eduemploy 	=	3	if	plg0014>=1 & plg0014<=6					
replace eduemploy	=	0	if 	plb0022==1 & plg0012!=1		| 					///
								eduemploy==. & plb0022==6 	| 					///
								eduemploy==. & plb0022==7		
replace eduemploy	=	4	if 	plb0022==9 & plg0012==2 	| 					///
								eduemploy==. & age!=min_age
replace eduemploy	=	5	if 	plb0021==1

gen eduemployyouth		=	0	if  jl0013==1	& 	jl0125==6 & age==min_age
replace eduemployyouth	=	1	if	jl0125>=1 	&	jl0125<5 | jl0125>=7
replace eduemployyouth	=	2	if	jl0125==5
replace eduemployyouth	=	3	if 	jl1402==1
replace eduemployyouth	=	4	if	jl0013==2	&	jl0125==6

replace eduemploy = eduemployyouth if age==min_age & eduemploy==. 
		
recode eduemploy	(0 		=	0  	"Employed") 									///
					(1		=	1	"General education")							///
					(2		=	2	"Vocational education")							///
					(3		=	3	"Higher education")								///
					(4		=	4	"Not employed, not in education")				///
					(5		=	5	"Unemployed")									///
					, gen(eduemp) 	

** Turning poinst employment status (used in returning home analysis)
// make reduced version of this variable
recode eduemp (0 = 0 "employed") (1 2 3 = 1 "education") (4 5 = 4 "unemployed") 	///
					, gen(eduempb) 

// Changed both if it is different now than n-1, or if it is different in n-1 compared to n-2
sort pid syear
gen turning = . 
bys pid: replace turning = 1 if eduempb==0 & eduempb[_n-1]==0 & eduempb[_n-2]==0 & turning==. |  /// 
								eduempb==0 & eduempb[_n-1]==0 & eduempb[_n-2]==. & turning==.
bys pid: replace turning = 2 if eduempb==1 & eduempb[_n-1]==1 & eduempb[_n-2]==1 & turning==. |	/// 
								eduempb==1 & eduempb[_n-1]==1 & eduempb[_n-2]==. & turning==.
bys pid: replace turning = 3 if eduempb==4 & eduempb[_n-1]==4 & eduempb[_n-2]==4 & turning==.|	/// 
								eduempb==4 & eduempb[_n-1]==4 & eduempb[_n-2]==. & turning==.
bys pid: replace turning = 4 if eduempb==0 & eduempb[_n-1]==1 					 & turning==. |	/// 
								eduempb==0 & eduempb[_n-1]==0 & eduempb[_n-2]==1 & turning==. 
bys pid: replace turning = 6 if eduempb==4 & eduempb[_n-1]==1 					 & turning==. |	/// 
								eduempb==4 & eduempb[_n-1]==4 & eduempb[_n-2]==1 & turning==.								
bys pid: replace turning = 5 if eduempb==0 & eduempb[_n-1]==4 					 & turning==.|	/// 
								eduempb==0 & eduempb[_n-1]==0 & eduempb[_n-2]==4 & turning==.								
bys pid: replace turning = 7 if eduempb==4 & eduempb[_n-1]==0 					 & turning==.|	///
								eduempb==4 & eduempb[_n-1]==4 & eduempb[_n-2]==0 & turning==.								
bys pid: replace turning = 8 if eduempb==1 & eduempb[_n-1]==0 					 & turning==. |	///
								eduempb==1 & eduempb[_n-1]==1 & eduempb[_n-2]==0 & turning==.	
bys pid: replace turning = 9 if eduempb==1 & eduempb[_n-1]==4					 & turning==. | ///
								eduempb==1 & eduempb[_n-1]==1 & eduempb[_n-2]==4 & turning==.									
								
recode turning 	(1 	= 	1	"Stable employed") 						///
				(2	=	2	"Stable in education")					///
				(3 	=	3	"Stable unemployed or incative")		///
				(4	=	4	"Student to employed")					///
				(5	=	5	"Unemployed or inactive to employed")	///
				(6	=	6	"Student to unemployed or inactive")	///
				(7	=	7	"Employed to unemployed or inactive")	///
				(8 	=	8	"Employed to student")					///
				(9	=	9	"Unemployed to student"), gen(empstat) 

				
* Partner/relationship variables				
** In a steady relationship, partner (used in leaving home analysis) 
fre pld0132
gen partner=.
replace partner = 1 if 	pld0132==1 | pgfamstd==1 | pgfamstd==7 | pld0133==1 			|  	///
						age==min_age & jl0038>=1 & jl0038<6 
replace partner = 0 if  partner==. & pld0132==2 | partner==. &  age==min_age & jl0038==6 |	///
						pgfamstd==3 & partner==.
sort pid syear
bys pid: replace partner = partner[_n-1] if partner==. 

** Boomerang variables (used in returning home analysis), unpartnered and partnered  
// Changed both if it is different now than n-1, or if it is different in n-1 compared to n-2
recode pgfamstd		(1 6 7 		=	1	"Partner") 		///
					(else		=	0	"Single")		///
					, gen(partnerb)				
replace partnerb = 1 	if 	pld0133==1 | pld0133==-8 & pgpartz==2
replace partnerb = 0	if 	jl0038==6  | pld0133==2

gen partnerturn = .
bys pid: replace partnerturn = 1 if 	partnerb==1	& partnerb[_n-1]==1 & partnerb[_n-2]!=0		 
bys pid: replace partnerturn = 2 if 	partnerb==0 & partnerb[_n-1]==0 & partnerb[_n-2]==0 	 
bys pid: replace partnerturn = 3 if 	partnerb==1 & partnerb[_n-1]==0 |						/// 
										partnerb==1 & partnerb[_n-1]==1 & partnerb[_n-2]==0
bys pid: replace partnerturn = 4 if 	partnerb==0 & partnerb[_n-1]==1 |						/// 
										partnerb==0 & partnerb[_n-1]==0 & partnerb[_n-2]==1

recode partnerturn 	(1 	= 	1	"Stable partnered") 					///
					(2	=	2	"Stable unpartnered")					///
					(3 	=	3	"Recently partnered")					///
					(4 	=	4	"Recently unpartnered"), gen(partnerstat)									

gen unpartnered=0 
gen partnered=0 

sort pid syear
foreach num of numlist 1 2 3 4 5 {
	bys pid: replace unpartnered=1 if partnerstat==4 | partnerstat[_n-`num']==4
	}
	*
foreach num of numlist 1 2 3 4 5 {
	bys pid: replace partnered=1 if partnerstat==3 | partnerstat[_n-`num']==3 | ///
									partnerstat==1 | partnerstat[_n-`num']==1
	}
	*		
	
*-----------------------------------------------------------------------------*
***** Variables of the parents

* Average life satisfaction of the parent or partner, lsatp
foreach var of varlist bioxplh0182 bio2xplh0182   ///
bioxpartlifes bio2xpartlifes {
	recode `var' (-5 -2 -1 = . )
	sort pid syear
	bys pid: replace `var' = `var'[_n-1] if `var'==.
	bys pid: replace `var' = `var'[_n+1] if `var'==.
	}
	*
																						
gen 	lsatp 	= 	bioxplh0182  						if 	resid==1 					| ///
					resid==3 & bio2xplh0182==.
replace lsatp 	= 	bio2xplh0182 						if 	resid==2 					| ///
					resid==3 & bioxplh0182==.  											
replace lsatp 	=	(bioxplh0182 + bio2xplh0182)/2  	if	resid==3 & bioxplh0182!=. & bio2xplh0182!=.
replace lsatp 	= 	(bioxplh0182 + bioxpartlifes)/2 	if	resid==1 & bioxplh0182!=. & bioxpartlifes!=.
replace lsatp 	= 	(bioxplh0182 + bio2xpartlifes)/2  	if	resid==2 & bioxplh0182!=. & bio2xpartlifes!=.
					
* Family structure
** First make age at each status
foreach x of newlist biox bio2x { 
	foreach num of numlist 1/10 {
		gen `x'age`num' = `x'ymar`num'- gebjahr
		}
		*
** Pointer to important syears: ymar: marstat before birth child, ymarb: marstat when child started jugendl
gen `x'ymara=.
gen `x'ymarb=. 
gen `x'mary0=. 

foreach num of numlist 1/10 { 
	replace `x'ymara 	= `num' 	if `x'age`num'<=0 
	replace `x'ymarb 	= `num' 	if `x'age`num'<=min_age
	replace `x'mary0	= 1 		if `x'ymara==`num' & `x'mar`num'!=1
	}
	*

foreach num of numlist 1/10 { 
	replace `x'ymara	= `num' 	if `x'age`num'>0 & `x'age`num'<4 & `x'mary0==. & `x'mar`num'==1
	}
	*
replace `x'ymara = 1 if `x'ymara==. 		// parents who only are observed after child was born

gen `x'mara = . 
foreach num of numlist 1/10 {
	replace `x'mara  = `x'mar`num' if `x'ymara==`num'
	}
	*

** Partnernumber in year child was younger than 1 and when child is 17
gen `x'p1=. 
gen `x'p2 = .
tostring `x'p1 `x'p2, replace
foreach num of numlist 1/10 {
	replace `x'p1 = `x'partmar`num' 	if `x'ymara==`num'
	replace `x'p2 = `x'partmar`num' 	if `x'ymarb==`num'
	}
	*
replace `x'p1 = "." if `x'p1== "-2"
replace `x'p2 = "." if `x'p2== "-2"

** Variable whether parent was ever single/divorced, widowed or married before jugendl
foreach b of newlist `x'div `x'wid `x'marb {
	gen `b'=0
	}
	*
foreach num of numlist 1/10 {
	replace `x'div 		= 	1 if 	`num'==`x'ymara & `x'mar`num'!=1 			| ///
									`num'>`x'ymara & `num'<=`x'ymarb & `x'mar`num'==2 	
	replace `x'wid 		= 	1 if 	`num'>`x'ymara & `num'<=`x'ymarb & `x'mar`num'==3 
	replace `x'marb 	= 	1 if 	`x'ymarb==`num' & `x'mar`num'==1
		}
	*

** Make familystructure variable 
gen `x'fam =. 
replace `x'fam		=	1	if 	`x'mara==1 &  `x'marb==1 & `x'div==0 & `x'wid==0 | 	///  
								`x'mara==1 &  `x'marb==1 &  `x'p1==`x'p2 & 			///
								`x'p1!="." & `x'div==1 & `x'wid==0			
replace `x'fam		=	2 	if 	`x'mara==1 & `x'div==1 & `x'fam==. & `x'wid==0 	 	
replace `x'fam 		= 	3	if 	`x'div==1 & `x'wid==0 								
replace `x'fam 		= 	4 	if 	`x'wid==1 & `x'marb==1									
replace `x'fam 		= 	5 	if 	`x'wid==1 & `x'marb==3 										

** Make variable marry and divorce if custodial parent marries or divorces after age 17
gen `x'marry   =	0	
gen `x'divorce = 	0
gen `x'widow	=	0

replace `x'fam 	= 	2	if 	`x'fam<4 & 	`x'famstat==1 & `x'div==1 				|	///
							`x'fam<4 & 	`x'famstat==1 & `x'famstatbf>1 & `x'famstatbf<4
replace `x'fam 	=	3	if 	`x'fam<4 & 	`x'famstat==2 
replace `x'fam	=	4	if 	`x'famstat==1 & `x'famstatbf==3
replace `x'fam	=	5	if	`x'famstat==3
		}
		*
		
gen 	fama = bioxfam if 		resid==1 | resid==3
replace fama = bio2xfam if 		resid==2 | fama==.
recode fama		(1		=	1	"Intact")								///
				(2  	= 	2	"Separated, no stepparent")				///
				(3  	= 	3	"Separated, with stepparent")			///
				(5 4 	= 	4	"Widowed") 								///
				, gen(fam) 
bys pid: egen fammode = mode(fam)
replace fam = fammode if fam==. & fammode!=. 


*-----------------------------------------------------------------------------*
***** Some additional actions

* Number of waves since leaving home, n2
gen n2 = n-nmov

* Lag variables
drop n
sort pid syear
bys pid: gen n = _n
foreach var of varlist 	pmic lsat lsatp hsat dsat hcon owner hhdmem eduemp 	  ///
		partner fam region poor   {
	sort pid syear
	bys pid: gen `var'lag 			= 	`var'[_n-1] 
	replace `var'lag				=	`var'		if 	n==1 
	bys pid: replace `var'lag 		=	`var'[_n-2] if `var'lag==. 
	}
	*

* maximum years etc. 
bys pid: egen evmoved = max(leaveh)
gen ageret = age if return==1
bys pid: egen min_agert = min(ageret) 
bys pid: egen maxsyear = max(syear)
bys pid: egen maxn2 = max(n2)

* change in life, health and dwelling satisfaction 
foreach var of varlist  lsat  hsat dsat  { 
gen `var'1a = `var'lag if n2==0
bys pid: egen `var'1 = max(`var'1a)
gen `var'change = `var'lag - `var'1
}
*

/*-----------------------------------------------------------------------------
	Sample selection 
-----------------------------------------------------------------------------*/
* Drop people who are only observed once or started after age 23
keep if min_age<23
drop if n==1 

* Drop people who have no resident parent
drop if hid!=bioxhid & hid!=bio2xhid & n<nmov 
gen mis = 1 if famlag==. & nmov==. | famlag==. & nmov>n 
bys pid: egen max_mix = max(mis)
drop if mis==1

bys pid: gen famlag2 = famlag[_n-1]
replace famlag = famlag2 if famlag==. & n==nmov

* Drop if missing information one of the key variables
gen missing = 1 if 	pmiclag==5 		| lsatlag==. 	| hconlag==. 	| 				///
					ownerlag==. 	| eduemplag==. 	| partnerlag==. |				///
					famlag==. 		| regionlag==2 	| mig==.		|				///
					lsatplag==.  	| hsatlag==.
replace missing = 0 if age>35 | n>nmov
bys pid: egen max_miss = max(missing)
drop if max_miss==1 // 13.140
distinct pid

save "${posted}\data.dta", replace

